<?php

namespace Drupal\session_inspector;

use Drupal\Core\Session\AccountInterface;

/**
 * An interface for inspecting and deactivating sessions.
 *
 * @package Drupal\session_inspector
 */
interface SessionInspectorInterface {

  /**
   * Get all of the sesions belonging to the user passed.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user account to use to find the sessions.
   *
   * @return array
   *   An array of sessions information.
   */
  public function getSessions(AccountInterface $account): array;

  /**
   * Get a single session.
   *
   * @param string $sid
   *   The session ID.
   *
   * @return array
   *   The session data.
   */
  public function getSession($sid): array;

  /**
   * Deletes a session with a given session ID.
   *
   * @param string $session_id
   *   The session ID to delete.
   */
  public function destroySession(string $session_id):void;

}
